@@ -14,13 +14,13 @@ function(language = "en", kind = "person", probs = FALSE, model = NULL)
 {
     info <- if(is.null(model)) {
         language <- match.arg(language, openNLP_languages)
-        ## <FIXME>
-        ## Should this be called 'type' instead?
+        ## <NOTE>
+        ## Alternatively could have used 'type' instead of 'kind' ...
         kind <- match.arg(kind,
                           ## Should be good enough for now ...
                           c("date", "location", "money", "organization",
                             "percentage", "person", "misc"))
-        ## </FIXME>
+        ## </NOTE>
         package <- sprintf("openNLPmodels.%s", language)
         model <- system.file("models",
                              sprintf("%s-ner-%s.bin", language, kind),
@@ -30,7 +30,7 @@ function(language = "en", kind = "person", probs = FALSE, model = NULL)
                 paste(gettextf("Could not find model file for language '%s' and kind '%s'.",
                                language, kind),
                       if(system.file(package = package) == "") {
-                          gettextf("Please make sure package '%s' is installed,\navailable from http://datacube.wu.ac.at/.",
+                          gettextf("Please make sure package '%s' is installed,\navailable from <http://datacube.wu.ac.at/>.",
                                    package)
                       } else {
                           gettextf("Apparently, package '%s' is installed\nbut does not provide this model.",
@@ -39,14 +39,14 @@ function(language = "en", kind = "person", probs = FALSE, model = NULL)
                       sep = "\n")
             stop(msg)            
         }
-        sprintf("the default model for language '%s' and kind '%s'.",
+        sprintf("the default model for language '%s' and kind '%s'",
                 language, kind)
     }
     else
-        "a user-defined model."
+        "a user-defined model"
 
     ## See
-    ## http://opennlp.apache.org/documentation/1.5.3/manual/opennlp.html#tools.namefind.recognition.api
+    ## <http://opennlp.apache.org/documentation/1.5.3/manual/opennlp.html#tools.namefind.recognition.api>.
 
     model <- .jnew("opennlp.tools.namefind.TokenNameFinderModel",
                    .jcast(.jnew("java.io.FileInputStream", model),
@@ -68,7 +68,7 @@ function(language = "en", kind = "person", probs = FALSE, model = NULL)
             if(probs) {
                 ## Apparently need the probabilities for the obtained
                 ## spans, see
-                ## http://opennlp.apache.org/documentation/1.5.3/apidocs/opennlp-tools/index.html.
+                ## <http://opennlp.apache.org/documentation/1.5.3/apidocs/opennlp-tools/index.html>.
                 probs <- .jcall(ref, "[D", "probs",
                                 .jcast(.jarray(y),
                                        "[Lopennlp/tools/util/Span;"))
