@@ -26,7 +26,7 @@ function(language = "en", probs = FALSE, model = NULL)
                 paste(gettextf("Could not find model file for language '%s'.",
                                language),
                       if(system.file(package = package) == "") {
-                          gettextf("Please make sure package '%s' is installed,\navailable from http://datacube.wu.ac.at/.",
+                          gettextf("Please make sure package '%s' is installed,\navailable from <http://datacube.wu.ac.at/>.",
                                    package)
                       } else {
                           gettextf("Apparently, package '%s' is installed\nbut does not provide this model.",
@@ -41,7 +41,7 @@ function(language = "en", probs = FALSE, model = NULL)
         "a user-defined model"
 
     ## See
-    ## http://opennlp.apache.org/documentation/1.5.3/manual/opennlp.html#tools.sentdetect.detection.api
+    ## <http://opennlp.apache.org/documentation/1.5.3/manual/opennlp.html#tools.sentdetect.detection.api>.
 
     model <- .jnew("opennlp.tools.sentdetect.SentenceModel",
                    .jcast(.jnew("java.io.FileInputStream", model),
