@@ -26,7 +26,7 @@ function(language = "en", probs = FALSE, model = NULL)
                 paste(gettextf("Could not find model file for language '%s'.",
                                language),
                       if(system.file(package = package) == "") {
-                          gettextf("Please make sure package '%s' is installed,\navailable from http://datacube.wu.ac.at/.",
+                          gettextf("Please make sure package '%s' is installed,\navailable from <http://datacube.wu.ac.at/>.",
                                    package)
                       } else {
                           gettextf("Apparently, package '%s' is installed\nbut does not provide this model.",
@@ -35,13 +35,13 @@ function(language = "en", probs = FALSE, model = NULL)
                       sep = "\n")
             stop(msg)
         }
-        sprintf("the default model for language '%s'.", language)
+        sprintf("the default model for language '%s'", language)
     }
     else
-        "a user-defined model."
+        "a user-defined model"
 
     ## See
-    ## http://opennlp.apache.org/documentation/1.5.3/manual/opennlp.html#tools.tokenizer.api
+    ## <http://opennlp.apache.org/documentation/1.5.3/manual/opennlp.html#tools.tokenizer.api>.
 
     model <- .jnew("opennlp.tools.tokenize.TokenizerModel",
                    .jcast(.jnew("java.io.FileInputStream", model),
